================
``desmod.queue``
================

.. automodule:: desmod.queue

.. autoclass:: Queue
   :members:

.. autoclass:: PriorityQueue
   :inherited-members:
   :members:

.. autoclass:: PriorityItem
   :members: priority, item
